@@ -31,7 +31,7 @@
 # and performs various validations against the upgraded version.
 
 
-MAX_STEPS=17
+MAX_STEPS=$(( $(grep -c "Msg " "$0") - 2)) # subtract self line and the function name
 CUR_STEP=1
 RELEASE_DELTA="${RELEASE_DELTA:-1}"
 HCO_DEPLOYMENT_NAME=hco-operator
@@ -43,6 +43,8 @@ PACKAGE_DIR="./deploy/olm-catalog/community-kubevirt-hyperconverged"
 INITIAL_CHANNEL=$(ls -d ${PACKAGE_DIR}/*/ | sort -rV | awk "NR==${RELEASE_DELTA}" | cut -d '/' -f 5)
 TARGET_VERSION=100.0.0
 TARGET_CHANNEL=${TARGET_VERSION}
+VMS_NAMESPACE=vmsns
+
 echo "INITIAL_CHANNEL: $INITIAL_CHANNEL"
 
 function Msg {
@@ -70,6 +72,13 @@ function cleanup() {
 
 trap "cleanup" INT TERM EXIT
 
+echo "----- Set KVM_EMULATION if needed"
+if [[ -n "${KVM_EMULATION}" ]]; then
+  ${CMD} patch $(${CMD} get subscription -n "${HCO_NAMESPACE}" -o name) -n "${HCO_NAMESPACE}" -p '{"spec":{"config":{"selector":{"matchLabels":{"name":"hyperconverged-cluster-operator"}},"env":[{"name":"KVM_EMULATION","value":"true"}]}}}' --type=merge
+  sleep 30
+  ${CMD} wait deployment ${HCO_DEPLOYMENT_NAME} --for condition=Available -n ${HCO_NAMESPACE} --timeout="30m"
+  ${CMD} wait deployment ${HCO_WH_DEPLOYMENT_NAME} --for condition=Available -n ${HCO_NAMESPACE} --timeout="30m"
+fi
 
 source hack/compare_scc.sh
 dump_sccs_before
@@ -92,6 +101,23 @@ echo "----- Images before upgrade"
 ${CMD} get deployments -n ${HCO_NAMESPACE} -o yaml | grep image | grep -v imagePullPolicy
 ${CMD} get pod $HCO_CATALOGSOURCE_POD -n ${HCO_CATALOG_NAMESPACE} -o yaml | grep image | grep -v imagePullPolicy
 
+echo "----- Get virtctl"
+KV_VERSION=$( ${CMD} get kubevirt.kubevirt.io/kubevirt-kubevirt-hyperconverged -n ${HCO_NAMESPACE} -o=jsonpath="{.status.observedKubeVirtVersion}")
+ARCH=$(uname -s | tr A-Z a-z)-$(uname -m | sed 's/x86_64/amd64/') || windows-amd64.exe
+echo ${ARCH}
+curl -L -o ~/virtctl https://github.com/kubevirt/kubevirt/releases/download/${KV_VERSION}/virtctl-${KV_VERSION}-${ARCH}
+chmod +x ~/virtctl
+###################
+
+### Create a VM ###
+Msg "Create a simple VM on the previous version cluster, before the upgrade"
+${CMD} create namespace ${VMS_NAMESPACE}
+${CMD} apply -n ${VMS_NAMESPACE} -f ./hack/vm.yaml
+${CMD} get vm -n ${VMS_NAMESPACE} -o yaml testvm
+~/virtctl start testvm -n ${VMS_NAMESPACE}
+./hack/retry.sh 30 10 "${CMD} get vmi -n ${VMS_NAMESPACE} testvm -o jsonpath='{ .status.phase }' | grep 'Running'"
+${CMD} get vmi -n ${VMS_NAMESPACE} -o yaml testvm
+INITIAL_BOOTTIME=$(./hack/vmuptime.ext | grep "^BOOTTIME" | cut -d= -f2 | tr -dc '[:digit:]')
 
 echo "----- HCO deployOVS annotation and OVS state in CNAO CR before the upgrade"
 PREVIOUS_OVS_ANNOTATION=$(${CMD} get ${HCO_KIND} ${HCO_RESOURCE_NAME} -n ${HCO_NAMESPACE} -o jsonpath='{.metadata.annotations.deployOVS}')
@@ -120,14 +146,6 @@ HCO_SUBSCRIPTION=$(${CMD} get subscription -n ${HCO_NAMESPACE} -o name)
 OLD_INSTALL_PLAN=$(oc -n "${HCO_NAMESPACE}" get "${HCO_SUBSCRIPTION}" -o jsonpath='{.status.installplan.name}')
 ${CMD} patch ${HCO_SUBSCRIPTION} -n ${HCO_NAMESPACE} -p "{\"spec\": {\"channel\": \"${TARGET_CHANNEL}\"}}"  --type merge
 
-# TEMP HACK TO UNLOCK UPGRADE
-sleep 15
-for OLM_APP_LABEL in olm-operator catalog-operator
-do
-  ${CMD} delete -n openshift-operator-lifecycle-manager "$(${CMD} get pod -n openshift-operator-lifecycle-manager -l app=${OLM_APP_LABEL} -o name)"
-done
-# ###########################
-
 Msg "Wait up to 5 minutes for the new installPlan to appear, and approve it to begin upgrade"
 INSTALL_PLAN_APPROVED=false
 for _ in $(seq 1 60); do
@@ -163,8 +181,8 @@ Msg "Verify the subscription's currentCSV and installedCSV have moved to the new
 ${CMD} get pods -n ${HCO_NAMESPACE}
 ./hack/retry.sh 30 60 "${CMD} get deployment -n ${HCO_NAMESPACE} | grep ${HCO_DEPLOYMENT_NAME}"
 
-${CMD} wait deployment ${HCO_DEPLOYMENT_NAME} --for condition=Available -n ${HCO_NAMESPACE} --timeout="30m"
-${CMD} wait deployment ${HCO_WH_DEPLOYMENT_NAME} --for condition=Available -n ${HCO_NAMESPACE} --timeout="30m"
+${CMD} wait deployment ${HCO_DEPLOYMENT_NAME} --for condition=Available -n ${HCO_NAMESPACE} --timeout="1200s"
+${CMD} wait deployment ${HCO_WH_DEPLOYMENT_NAME} --for condition=Available -n ${HCO_NAMESPACE} --timeout="1200s"
 
 ./hack/retry.sh 30 60 "${CMD} get subscriptions -n ${HCO_NAMESPACE} -o yaml | grep currentCSV   | grep v${TARGET_VERSION}"
 ./hack/retry.sh  2 30 "${CMD} get subscriptions -n ${HCO_NAMESPACE} -o yaml | grep installedCSV | grep v${TARGET_VERSION}"
@@ -214,6 +232,22 @@ ${CMD} get pod $HCO_CATALOGSOURCE_POD -n ${HCO_CATALOG_NAMESPACE} -o yaml | grep
 
 dump_sccs_after
 
+Msg "make sure that the VM is still running, after the upgrade"
+${CMD} get vm -n ${VMS_NAMESPACE} -o yaml testvm
+${CMD} get vmi -n ${VMS_NAMESPACE} -o yaml testvm
+${CMD} get vmi -n ${VMS_NAMESPACE} testvm -o jsonpath='{ .status.phase }' | grep 'Running'
+CURRENT_BOOTTIME=$(./hack/vmuptime.ext | grep "^BOOTTIME" | cut -d= -f2 | tr -dc '[:digit:]')
+
+if ((INITIAL_BOOTTIME - CURRENT_BOOTTIME > 3)) || ((CURRENT_BOOTTIME - INITIAL_BOOTTIME > 3)); then
+    echo "ERROR: The test VM got restarted during the upgrade process."
+    exit 1
+else
+    echo "The test VM survived the upgrade process."
+fi
+
+~/virtctl stop testvm -n ${VMS_NAMESPACE}
+${CMD} delete vm -n ${VMS_NAMESPACE} testvm
+
 KUBECTL_BINARY=${CMD} ./hack/test_quick_start.sh
 
 Msg "Check that OVS is deployed or not deployed according to deployOVS annotation in HCO CR."
