@@ -9,7 +9,6 @@ import (
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
 	conditionsv1 "github.com/openshift/custom-resource-status/conditions/v1"
-	"github.com/openshift/custom-resource-status/testlib"
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -75,21 +74,21 @@ var _ = Describe("CDI Operand", func() {
 			// ObjectReference should have been added
 			Expect(hco.Status.RelatedObjects).To(ContainElement(*objectRef))
 			// Check conditions
-			Expect(req.Conditions[conditionsv1.ConditionAvailable]).To(testlib.RepresentCondition(conditionsv1.Condition{
-				Type:    conditionsv1.ConditionAvailable,
-				Status:  corev1.ConditionFalse,
+			Expect(req.Conditions[hcov1beta1.ConditionAvailable]).To(commonTestUtils.RepresentCondition(metav1.Condition{
+				Type:    hcov1beta1.ConditionAvailable,
+				Status:  metav1.ConditionFalse,
 				Reason:  "CDIConditions",
 				Message: "CDI resource has no conditions",
 			}))
-			Expect(req.Conditions[conditionsv1.ConditionProgressing]).To(testlib.RepresentCondition(conditionsv1.Condition{
-				Type:    conditionsv1.ConditionProgressing,
-				Status:  corev1.ConditionTrue,
+			Expect(req.Conditions[hcov1beta1.ConditionProgressing]).To(commonTestUtils.RepresentCondition(metav1.Condition{
+				Type:    hcov1beta1.ConditionProgressing,
+				Status:  metav1.ConditionTrue,
 				Reason:  "CDIConditions",
 				Message: "CDI resource has no conditions",
 			}))
-			Expect(req.Conditions[conditionsv1.ConditionUpgradeable]).To(testlib.RepresentCondition(conditionsv1.Condition{
-				Type:    conditionsv1.ConditionUpgradeable,
-				Status:  corev1.ConditionFalse,
+			Expect(req.Conditions[hcov1beta1.ConditionUpgradeable]).To(commonTestUtils.RepresentCondition(metav1.Condition{
+				Type:    hcov1beta1.ConditionUpgradeable,
+				Status:  metav1.ConditionFalse,
 				Reason:  "CDIConditions",
 				Message: "CDI resource has no conditions",
 			}))
@@ -783,19 +782,19 @@ var _ = Describe("CDI Operand", func() {
 			Expect(err).ToNot(HaveOccurred())
 			expectedResource.ObjectMeta.SelfLink = fmt.Sprintf("/apis/v1/namespaces/%s/dummies/%s", expectedResource.Namespace, expectedResource.Name)
 			expectedResource.Status.Conditions = []conditionsv1.Condition{
-				conditionsv1.Condition{
+				{
 					Type:    conditionsv1.ConditionAvailable,
 					Status:  corev1.ConditionFalse,
 					Reason:  "Foo",
 					Message: "Bar",
 				},
-				conditionsv1.Condition{
+				{
 					Type:    conditionsv1.ConditionProgressing,
 					Status:  corev1.ConditionTrue,
 					Reason:  "Foo",
 					Message: "Bar",
 				},
-				conditionsv1.Condition{
+				{
 					Type:    conditionsv1.ConditionDegraded,
 					Status:  corev1.ConditionTrue,
 					Reason:  "Foo",
@@ -815,27 +814,27 @@ var _ = Describe("CDI Operand", func() {
 			// ObjectReference should have been added
 			Expect(hco.Status.RelatedObjects).To(ContainElement(*objectRef))
 			// Check conditions
-			Expect(req.Conditions[conditionsv1.ConditionAvailable]).To(testlib.RepresentCondition(conditionsv1.Condition{
-				Type:    conditionsv1.ConditionAvailable,
-				Status:  corev1.ConditionFalse,
+			Expect(req.Conditions[hcov1beta1.ConditionAvailable]).To(commonTestUtils.RepresentCondition(metav1.Condition{
+				Type:    hcov1beta1.ConditionAvailable,
+				Status:  metav1.ConditionFalse,
 				Reason:  "CDINotAvailable",
 				Message: "CDI is not available: Bar",
 			}))
-			Expect(req.Conditions[conditionsv1.ConditionProgressing]).To(testlib.RepresentCondition(conditionsv1.Condition{
-				Type:    conditionsv1.ConditionProgressing,
-				Status:  corev1.ConditionTrue,
+			Expect(req.Conditions[hcov1beta1.ConditionProgressing]).To(commonTestUtils.RepresentCondition(metav1.Condition{
+				Type:    hcov1beta1.ConditionProgressing,
+				Status:  metav1.ConditionTrue,
 				Reason:  "CDIProgressing",
 				Message: "CDI is progressing: Bar",
 			}))
-			Expect(req.Conditions[conditionsv1.ConditionUpgradeable]).To(testlib.RepresentCondition(conditionsv1.Condition{
-				Type:    conditionsv1.ConditionUpgradeable,
-				Status:  corev1.ConditionFalse,
+			Expect(req.Conditions[hcov1beta1.ConditionUpgradeable]).To(commonTestUtils.RepresentCondition(metav1.Condition{
+				Type:    hcov1beta1.ConditionUpgradeable,
+				Status:  metav1.ConditionFalse,
 				Reason:  "CDIProgressing",
 				Message: "CDI is progressing: Bar",
 			}))
-			Expect(req.Conditions[conditionsv1.ConditionDegraded]).To(testlib.RepresentCondition(conditionsv1.Condition{
-				Type:    conditionsv1.ConditionDegraded,
-				Status:  corev1.ConditionTrue,
+			Expect(req.Conditions[hcov1beta1.ConditionDegraded]).To(commonTestUtils.RepresentCondition(metav1.Condition{
+				Type:    hcov1beta1.ConditionDegraded,
+				Status:  metav1.ConditionTrue,
 				Reason:  "CDIDegraded",
 				Message: "CDI is degraded: Bar",
 			}))
@@ -1068,15 +1067,12 @@ var _ = Describe("CDI Operand", func() {
 			})
 		})
 
-		Context("KubeVirt Storage Role", func() {
+		Context("Config Reader Role", func() {
 			It("should do nothing if exists", func() {
-				existsCdi, err := NewCDI(hco)
-				expectedRole := NewKubeVirtStorageRoleForCR(hco, hco.Namespace, commonTestUtils.GetScheme())
-				Expect(err).ToNot(HaveOccurred())
+				expectedRole := NewConfigReaderRoleForCR(hco, hco.Namespace)
+				cl := commonTestUtils.InitClient([]runtime.Object{hco, expectedRole})
 
-				cl := commonTestUtils.InitClient([]runtime.Object{hco, existsCdi, expectedRole})
-
-				handler := (*genericOperand)(newCdiHandler(cl, commonTestUtils.GetScheme()))
+				handler := (*genericOperand)(newConfigReaderRoleHandler(cl, commonTestUtils.GetScheme()))
 				res := handler.ensure(req)
 				Expect(res.Err).ToNot(HaveOccurred())
 
@@ -1092,15 +1088,13 @@ var _ = Describe("CDI Operand", func() {
 			})
 
 			It("should update if labels are missing", func() {
-				existsCdi, err := NewCDI(hco)
-				expectedRole := NewKubeVirtStorageRoleForCR(hco, hco.Namespace, commonTestUtils.GetScheme())
+				expectedRole := NewConfigReaderRoleForCR(hco, hco.Namespace)
 				expectedLabels := expectedRole.Labels
 				expectedRole.Labels = nil
-				Expect(err).ToNot(HaveOccurred())
 
-				cl := commonTestUtils.InitClient([]runtime.Object{hco, existsCdi, expectedRole})
+				cl := commonTestUtils.InitClient([]runtime.Object{hco, expectedRole})
 
-				handler := (*genericOperand)(newCdiHandler(cl, commonTestUtils.GetScheme()))
+				handler := (*genericOperand)(newConfigReaderRoleHandler(cl, commonTestUtils.GetScheme()))
 				res := handler.ensure(req)
 				Expect(res.Err).ToNot(HaveOccurred())
 
@@ -1115,16 +1109,13 @@ var _ = Describe("CDI Operand", func() {
 			})
 		})
 
-		Context("KubeVirt Storage Role Binding", func() {
-			scheme := commonTestUtils.GetScheme()
+		Context("Config Reader Role Binding", func() {
 			It("should do nothing if exists", func() {
-				existsCdi, err := NewCDI(hco)
-				expectedRoleBinding := NewKubeVirtStorageRoleBindingForCR(hco, hco.Namespace, scheme)
-				Expect(err).ToNot(HaveOccurred())
+				expectedRoleBinding := NewConfigReaderRoleBindingForCR(hco, hco.Namespace)
 
-				cl := commonTestUtils.InitClient([]runtime.Object{hco, existsCdi, expectedRoleBinding})
+				cl := commonTestUtils.InitClient([]runtime.Object{hco, expectedRoleBinding})
 
-				handler := (*genericOperand)(newCdiHandler(cl, commonTestUtils.GetScheme()))
+				handler := (*genericOperand)(newConfigReaderRoleBindingHandler(cl, commonTestUtils.GetScheme()))
 				res := handler.ensure(req)
 				Expect(res.Err).ToNot(HaveOccurred())
 
@@ -1139,15 +1130,13 @@ var _ = Describe("CDI Operand", func() {
 			})
 
 			It("should update if labels are missing", func() {
-				existsCdi, err := NewCDI(hco)
-				expectedRoleBinding := NewKubeVirtStorageRoleBindingForCR(hco, hco.Namespace, scheme)
+				expectedRoleBinding := NewConfigReaderRoleBindingForCR(hco, hco.Namespace)
 				expectedLabels := expectedRoleBinding.Labels
 				expectedRoleBinding.Labels = nil
-				Expect(err).ToNot(HaveOccurred())
 
-				cl := commonTestUtils.InitClient([]runtime.Object{hco, existsCdi, expectedRoleBinding})
+				cl := commonTestUtils.InitClient([]runtime.Object{hco, expectedRoleBinding})
 
-				handler := (*genericOperand)(newCdiHandler(cl, commonTestUtils.GetScheme()))
+				handler := (*genericOperand)(newConfigReaderRoleBindingHandler(cl, commonTestUtils.GetScheme()))
 				res := handler.ensure(req)
 				Expect(res.Err).ToNot(HaveOccurred())
 
